[−][src]Struct mdbook_epub::Config
The configuration struct used to tweak how an EPUB document is generated.
Fields
additional_css: Vec<PathBuf>A list of additional stylesheets to include in the document.
use_default_css: boolShould we use the default stylesheet (default: true)?
index_template: Option<PathBuf>The template file to use when rendering individual chapters (relative to the book root).
cover_image: Option<PathBuf>A cover image to use for the epub.
additional_resources: Vec<PathBuf>Additional assets to include in the ebook, such as typefaces.
Methods
impl Config[src]
pub fn from_render_context(ctx: &RenderContext) -> Result<Config, Error>[src]
Get the output.epub table from the provided book.toml config,
falling back to the default if
pub fn template(&self) -> Result<String, Error>[src]